@@ -66,6 +66,8 @@ init_IRQ()
 		VICVectAddress[i] = (volatile FP *)undef_interrupt;
 }
 
+extern unsigned int __data_start;
+
 /*
  * LPC2388のSRAM領域にFLASHのベクトルをコピーし、
  * リマップする。LPC2388共通で必要。
@@ -76,21 +78,54 @@ init_vector()
 	unsigned char *flash, *sram;
 	int i;
 
-	flash =(unsigned char*) 0;				/* FLASHの先頭アドレス */
-	sram = (unsigned char*) 0x40000000;	/* SRAMの先頭アドレス */
-
-		/* FLASHの先頭64バイトをSRAMにコピー */
-	for (i=0; i<64; i++)
+		/* ROM化コードとSRAM上で動くコードでは、例外ベクトルの扱いが違う。
+		 * ROM化する場合は、SRAM REMAPの前にFlash ROM上の例外ベクトルの値を
+		 * SRAM上のリマップ領域に移さなければならない。一方、SRAM上で動作する
+		 * 場合は、リマップ領域へはデバッガが初期値を書き込む。
+		 * このため、リマップ領域の初期化手順が必要か否かの判別を行う。判別は
+		 * __data_startの値を使う。この値はlpc2388_sram.ldの中で0に初期化して
+		 * いる。lpc2388.ldの中では非ゼロのアドレスが代入される。したがって、
+		 * リマップ領域の初期化は__data_startが非ゼロのときだけ行う。 */
+	if ( __data_start != 0 )
 	{
-		*sram = *flash;
-		sram++;
-		flash++;
-	}
+		flash =(unsigned char*) 0;				/* FLASHの先頭アドレス */
+		sram = (unsigned char*) 0x40000000;	/* SRAMの先頭アドレス */
 
+			/* FLASHの先頭64バイトをSRAMにコピー */
+		for (i=0; i<64; i++)
+		{
+			*sram = *flash;
+			sram++;
+			flash++;
+		}
+	}
 		/* SRAM をベクトルエリアにリマップする */
 	MEMMAP = 0x02;
 }
 
+/*
+ * LPC2388依存のUART初期化ルーチン。sys_putc()用にuart0を初期化する。
+ */
+#define	DLAB 0x80
+void
+init_uart0()
+{
+    /*
+     *  分周比の設定
+     */
+    /* Divisor Enable */
+	U0LCR |= DLAB;
+    U0DLL = UART0_DIVISOR & 0xFF ;
+    U0DLM = UART0_DIVISOR >> 8;
+    /* Divisor Disable */
+    U0LCR &= ~DLAB;
+
+    /* モード設定, パリティ無し 8bit data, 1 stop bit */
+    U0LCR = 0x03;
+
+    /* 割込み禁止 */
+    U0IER = 0;
+}
 
 /*
  *  システム終了フック。ファームウェアにシステム終了APIがあるなら
@@ -106,12 +141,22 @@ sys_exit()
 
 
 /*
- *  ターゲットシステムの文字出力
+ *  ターゲットシステムの文字出力。syslogタスクが起動する前にプリントを行うための
+ *  ルーチンであり、内部ではポーリングを行っている。LF記号が送られてきたら、
+ *  CR LFに変換してプリントする。sys_putcはデバイスを初期化しない。
+ *  初期化はkernel_start()の中で終わっていると仮定している。
  */
 
 void
 sys_putc(char c)
 {
+	if ( c== 0x0A )			/* もし LF ならば */
+		sys_putc( 0x0D );	/* CRを一文字送信 */
+
+	while( !( U0LSR & (1<<5)) )
+		;		/* UART0 LSRのTHREが1になるまで待つ。1ならば送信レジスタ空き。*/
+
+	U0THR = c;	/* 一文字送信 */
 }
 
 
