@@ -101,7 +101,7 @@ hw_timer_initialize()
 
 	T3CTCR = 0;			/* PCLKのエッジを数える。キャプチャ入力は無視 */
 	T3PR = 0;			/* PCLKのエッジをすべて数える。プリスケールなし */
-    T3MR3 = LP2388_SYSTEM_TIMER3_CLOCK / 1000;		/* 1mSごとにマッチさせる */
+    T3MR3 = (LP2388_SYSTEM_TIMER3_CLOCK/1000) -1;		/* 1mSごとにマッチさせる */
 	T3MCR = 0x3 << 9;	/* MR3S:R:I = 0:1:1。マッチしたらカウンタをリセットし、割り込みをかける */
 
 	T3TCR = 1;			/* TIMER3をカウント開始にする */
