@@ -114,6 +114,8 @@ sys_initialize()
 
     init_clock();			/* PLLの設定。システム固有 */
 
+    init_uart0();			/* UART0の初期化。システム固有 */
+
     init_IRQ();				/* VICを初期化する。LPC2388共通 */
 
     		/* 必要なペリフェラルの電源を入れる(システム固有) */
@@ -129,6 +131,14 @@ sys_initialize()
      */
     arm_install_handler(IRQ_Number,IRQ_Handler);
 
+    /*
+     * Memory Acceleration Moduleの設定 ( NXP社 UM10211 chapter 7 )
+     * Flashメモリのプリフェッチを使ってプログラム実行を高速化する
+     */
+    MAMCR = 0;		/* 念のためMAMをオフにする */
+    MAMTIM = 4;		/* UM10211によれば、60MHz以上で動作するときは4に設定する */
+    MAMCR = 2;		/* MAM機能をオンにする */
+
 }
 
 
